@@ -4,13 +4,14 @@ from .canvas import Canvas
 
 from .color_dialog import ColorDialog
 
-from .escapable_qlist_widget import EscapableQListWidget
-
 from .label_dialog import LabelDialog
 from .label_dialog import LabelQLineEdit
 
-from .label_qlist_widget import LabelQListWidget
+from .label_list_widget import LabelListWidget
+from .label_list_widget import LabelListWidgetItem
 
 from .tool_bar import ToolBar
 
+from .unique_label_qlist_widget import UniqueLabelQListWidget
+
 from .zoom_widget import ZoomWidget
